Turtle Plot Lib
=================

Simple project to provide a Graphic Turtle
interface to use inside Python's matplotlib graphics.

It is intendend to be used by Python learners that
primarily have a Jupyter notebook as Python environment
(even on the cloud, such as Google Colab)


Just use  "pip install turtleplotlib" to install and
```python

from turtleplotlib import Turtle

t = Turtle()
```
 to start using it.
